@@ -7,12 +7,9 @@ Extract the CAL-ACCESS raw data files from downloaded ZIP.
 import os
 import shutil
 import zipfile
-from django.core.files import File
 
 # Misc.
 import re
-import time
-from django.conf import settings
 from django.utils.timezone import now
 
 # Commands
@@ -72,9 +69,6 @@ class Command(CalAccessCommand):
 
         self.extract_tsv_files()
 
-        if getattr(settings, 'CALACCESS_STORE_ARCHIVE', False):
-            self.archive()
-
         if not options['keep_files']:
             shutil.rmtree(self.download_dir)
 
@@ -120,33 +114,3 @@ class Command(CalAccessCommand):
             raw_file.load_start_datetime = None
             raw_file.load_finish_datetime = None
             raw_file.save()
-
-    def archive(self, suffix=None):
-        """
-        Save a copy of the download zip file and each file inside.
-        """
-        if self.verbosity:
-            self.log(" Archiving original files")
-        if self.verbosity > 2:
-            self.log(" Archiving {}".format(os.path.basename(self.zip_path)))
-
-        identifier = "ccdc-raw-data-{dt:%Y-%m-%d_%H-%M-%S}".format(dt=self.version.release_datetime)
-        if suffix:
-            identifier += suffix
-
-        for raw_file in self.version.files.all():
-            if self.verbosity > 2:
-                self.log(" Archiving {0}.TSV".format(raw_file.file_name))
-            # Open up the .TSV file so we can wrap it in the Django File obj
-            file_path = os.path.join(self.tsv_dir, raw_file.file_name + '.TSV')
-            with open(file_path, 'rb') as f:
-                args = [identifier, File(f)]
-                # Save the .TSV on the raw data file
-                try:
-                    raw_file.download_file_archive.save(*args)
-                except FileExistsError:
-                    raw_file.download_file_archive.delete()
-                    raw_file.download_file_archive.save(*args)
-            time.sleep(0.25)
-
-        return identifier
